diff --git a/CHANGELOG.md b/CHANGELOG.md
index e846c5656c..563e372160 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -64,6 +64,7 @@ Ref: https://keepachangelog.com/en/1.0.0/
* (x/token) [\#609](https://github.com/line/lbm-sdk/pull/609) remove new APIs on x/token
* (x/collection) [\#621](https://github.com/line/lbm-sdk/pull/621) add additional information into EventXXXChanged
* (x/token) [\#636](https://github.com/line/lbm-sdk/pull/636) add creator into x/token EventIssue
+* (x/token) [\#637](https://github.com/line/lbm-sdk/pull/637) rename x/token events
### Bug Fixes
* (x/wasm) [\#453](https://github.com/line/lbm-sdk/pull/453) modify wasm grpc query api path
diff --git a/docs/core/proto-docs.md b/docs/core/proto-docs.md
index 81d71f0530..5c5b546cf4 100644
--- a/docs/core/proto-docs.md
+++ b/docs/core/proto-docs.md
@@ -1161,13 +1161,13 @@
- [Permission](#lbm.token.v1.Permission)
- [lbm/token/v1/event.proto](#lbm/token/v1/event.proto)
- - [EventAbandon](#lbm.token.v1.EventAbandon)
- [EventAuthorizedOperator](#lbm.token.v1.EventAuthorizedOperator)
- [EventBurned](#lbm.token.v1.EventBurned)
- - [EventGrant](#lbm.token.v1.EventGrant)
- - [EventIssue](#lbm.token.v1.EventIssue)
+ - [EventGranted](#lbm.token.v1.EventGranted)
+ - [EventIssued](#lbm.token.v1.EventIssued)
- [EventMinted](#lbm.token.v1.EventMinted)
- [EventModified](#lbm.token.v1.EventModified)
+ - [EventRenounced](#lbm.token.v1.EventRenounced)
- [EventRevokedOperator](#lbm.token.v1.EventRevokedOperator)
- [EventSent](#lbm.token.v1.EventSent)
@@ -17464,25 +17464,6 @@ Permission enumerates the valid permissions on a token class.
-
-
-### EventAbandon
-EventAbandon is emitted when a grantee abandons its permission.
-
-Since: 0.46.0 (finschia)
-
-
-| Field | Type | Label | Description |
-| ----- | ---- | ----- | ----------- |
-| `contract_id` | [string](#string) | | contract id associated with the token class. |
-| `grantee` | [string](#string) | | address of the grantee which abandons its grant. |
-| `permission` | [Permission](#lbm.token.v1.Permission) | | permission on the token class. |
-
-
-
-
-
-
### EventAuthorizedOperator
@@ -17522,10 +17503,10 @@ Since: 0.46.0 (finschia)
-
+
-### EventGrant
-EventGrant is emitted when a granter grants its permission to a grantee.
+### EventGranted
+EventGranted is emitted when a granter grants its permission to a grantee.
Info: `granter` would be empty if the permission is granted by an issuance.
@@ -17544,10 +17525,10 @@ Since: 0.46.0 (finschia)
-
+
-### EventIssue
-EventIssue is emitted when a new token class is created.
+### EventIssued
+EventIssued is emitted when a new token class is created.
Since: 0.46.0 (finschia)
@@ -17607,6 +17588,25 @@ Since: 0.46.0 (finschia)
+
+
+### EventRenounced
+EventRenounced is emitted when a grantee renounces its permission.
+
+Since: 0.46.0 (finschia)
+
+
+| Field | Type | Label | Description |
+| ----- | ---- | ----- | ----------- |
+| `contract_id` | [string](#string) | | contract id associated with the token class. |
+| `grantee` | [string](#string) | | address of the grantee which abandons its grant. |
+| `permission` | [Permission](#lbm.token.v1.Permission) | | permission on the token class. |
+
+
+
+
+
+
### EventRevokedOperator
diff --git a/x/token/event.go b/x/token/event.go
index 858a794a37..5b2e53a416 100644
--- a/x/token/event.go
+++ b/x/token/event.go
@@ -32,7 +32,7 @@ func AttributeKeyFromString(name string) AttributeKey {
return AttributeKey(AttributeKey_value[attributeKeyName])
}
-func NewEventIssueToken(event EventIssue, to sdk.AccAddress, amount sdk.Int) sdk.Event {
+func NewEventIssueToken(event EventIssued, to sdk.AccAddress, amount sdk.Int) sdk.Event {
eventType := EventTypeIssueToken.String()
attributes := map[AttributeKey]string{
AttributeKeyContractID: event.ContractId,
@@ -157,7 +157,7 @@ func NewEventTransferFrom(event EventSent) sdk.Event {
return res
}
-func NewEventGrantPermToken(event EventGrant) sdk.Event {
+func NewEventGrantPermToken(event EventGranted) sdk.Event {
eventType := EventTypeGrantPermToken.String()
attributes := map[AttributeKey]string{
AttributeKeyContractID: event.ContractId,
@@ -176,7 +176,7 @@ func NewEventGrantPermToken(event EventGrant) sdk.Event {
return res
}
-func NewEventGrantPermTokenHead(event EventGrant) sdk.Event {
+func NewEventGrantPermTokenHead(event EventGranted) sdk.Event {
eventType := EventTypeGrantPermToken.String()
attributes := map[AttributeKey]string{
AttributeKeyContractID: event.ContractId,
@@ -194,7 +194,7 @@ func NewEventGrantPermTokenHead(event EventGrant) sdk.Event {
return res
}
-func NewEventGrantPermTokenBody(event EventGrant) sdk.Event {
+func NewEventGrantPermTokenBody(event EventGranted) sdk.Event {
eventType := EventTypeGrantPermToken.String()
attributes := map[AttributeKey]string{
AttributeKeyPerm: LegacyPermission(event.Permission).String(),
@@ -208,7 +208,7 @@ func NewEventGrantPermTokenBody(event EventGrant) sdk.Event {
return res
}
-func NewEventRevokePermToken(event EventAbandon) sdk.Event {
+func NewEventRevokePermToken(event EventRenounced) sdk.Event {
eventType := EventTypeRevokePermToken.String()
attributes := map[AttributeKey]string{
AttributeKeyContractID: event.ContractId,
diff --git a/x/token/event.pb.go b/x/token/event.pb.go
index 83ad2b1863..07ae0154d3 100644
--- a/x/token/event.pb.go
+++ b/x/token/event.pb.go
@@ -345,10 +345,10 @@ func (m *EventRevokedOperator) GetOperator() string {
return ""
}
-// EventIssue is emitted when a new token class is created.
+// EventIssued is emitted when a new token class is created.
//
// Since: 0.46.0 (finschia)
-type EventIssue struct {
+type EventIssued struct {
// address which created the contract.
Creator string `protobuf:"bytes,1,opt,name=creator,proto3" json:"creator,omitempty"`
// contract id associated with the token class.
@@ -367,18 +367,18 @@ type EventIssue struct {
Mintable bool `protobuf:"varint,8,opt,name=mintable,proto3" json:"mintable,omitempty"`
}
-func (m *EventIssue) Reset() { *m = EventIssue{} }
-func (m *EventIssue) String() string { return proto.CompactTextString(m) }
-func (*EventIssue) ProtoMessage() {}
-func (*EventIssue) Descriptor() ([]byte, []int) {
+func (m *EventIssued) Reset() { *m = EventIssued{} }
+func (m *EventIssued) String() string { return proto.CompactTextString(m) }
+func (*EventIssued) ProtoMessage() {}
+func (*EventIssued) Descriptor() ([]byte, []int) {
return fileDescriptor_d7505f4c4cdec18e, []int{3}
}
-func (m *EventIssue) XXX_Unmarshal(b []byte) error {
+func (m *EventIssued) XXX_Unmarshal(b []byte) error {
return m.Unmarshal(b)
}
-func (m *EventIssue) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+func (m *EventIssued) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
if deterministic {
- return xxx_messageInfo_EventIssue.Marshal(b, m, deterministic)
+ return xxx_messageInfo_EventIssued.Marshal(b, m, deterministic)
} else {
b = b[:cap(b)]
n, err := m.MarshalToSizedBuffer(b)
@@ -388,80 +388,80 @@ func (m *EventIssue) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
return b[:n], nil
}
}
-func (m *EventIssue) XXX_Merge(src proto.Message) {
- xxx_messageInfo_EventIssue.Merge(m, src)
+func (m *EventIssued) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_EventIssued.Merge(m, src)
}
-func (m *EventIssue) XXX_Size() int {
+func (m *EventIssued) XXX_Size() int {
return m.Size()
}
-func (m *EventIssue) XXX_DiscardUnknown() {
- xxx_messageInfo_EventIssue.DiscardUnknown(m)
+func (m *EventIssued) XXX_DiscardUnknown() {
+ xxx_messageInfo_EventIssued.DiscardUnknown(m)
}
-var xxx_messageInfo_EventIssue proto.InternalMessageInfo
+var xxx_messageInfo_EventIssued proto.InternalMessageInfo
-func (m *EventIssue) GetCreator() string {
+func (m *EventIssued) GetCreator() string {
if m != nil {
return m.Creator
}
return ""
}
-func (m *EventIssue) GetContractId() string {
+func (m *EventIssued) GetContractId() string {
if m != nil {
return m.ContractId
}
return ""
}
-func (m *EventIssue) GetName() string {
+func (m *EventIssued) GetName() string {
if m != nil {
return m.Name
}
return ""
}
-func (m *EventIssue) GetSymbol() string {
+func (m *EventIssued) GetSymbol() string {
if m != nil {
return m.Symbol
}
return ""
}
-func (m *EventIssue) GetUri() string {
+func (m *EventIssued) GetUri() string {
if m != nil {
return m.Uri
}
return ""
}
-func (m *EventIssue) GetMeta() string {
+func (m *EventIssued) GetMeta() string {
if m != nil {
return m.Meta
}
return ""
}
-func (m *EventIssue) GetDecimals() int32 {
+func (m *EventIssued) GetDecimals() int32 {
if m != nil {
return m.Decimals
}
return 0
}
-func (m *EventIssue) GetMintable() bool {
+func (m *EventIssued) GetMintable() bool {
if m != nil {
return m.Mintable
}
return false
}
-// EventGrant is emitted when a granter grants its permission to a grantee.
+// EventGranted is emitted when a granter grants its permission to a grantee.
//
// Info: `granter` would be empty if the permission is granted by an issuance.
//
// Since: 0.46.0 (finschia)
-type EventGrant struct {
+type EventGranted struct {
// contract id associated with the token class.
ContractId string `protobuf:"bytes,1,opt,name=contract_id,json=contractId,proto3" json:"contract_id,omitempty"`
// address which granted the permission to `grantee`.
@@ -473,18 +473,18 @@ type EventGrant struct {
Permission Permission `protobuf:"varint,4,opt,name=permission,proto3,enum=lbm.token.v1.Permission" json:"permission,omitempty"`
}
-func (m *EventGrant) Reset() { *m = EventGrant{} }
-func (m *EventGrant) String() string { return proto.CompactTextString(m) }
-func (*EventGrant) ProtoMessage() {}
-func (*EventGrant) Descriptor() ([]byte, []int) {
+func (m *EventGranted) Reset() { *m = EventGranted{} }
+func (m *EventGranted) String() string { return proto.CompactTextString(m) }
+func (*EventGranted) ProtoMessage() {}
+func (*EventGranted) Descriptor() ([]byte, []int) {
return fileDescriptor_d7505f4c4cdec18e, []int{4}
}
-func (m *EventGrant) XXX_Unmarshal(b []byte) error {
+func (m *EventGranted) XXX_Unmarshal(b []byte) error {
return m.Unmarshal(b)
}
-func (m *EventGrant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+func (m *EventGranted) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
if deterministic {
- return xxx_messageInfo_EventGrant.Marshal(b, m, deterministic)
+ return xxx_messageInfo_EventGranted.Marshal(b, m, deterministic)
} else {
b = b[:cap(b)]
n, err := m.MarshalToSizedBuffer(b)
@@ -494,50 +494,50 @@ func (m *EventGrant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
return b[:n], nil
}
}
-func (m *EventGrant) XXX_Merge(src proto.Message) {
- xxx_messageInfo_EventGrant.Merge(m, src)
+func (m *EventGranted) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_EventGranted.Merge(m, src)
}
-func (m *EventGrant) XXX_Size() int {
+func (m *EventGranted) XXX_Size() int {
return m.Size()
}
-func (m *EventGrant) XXX_DiscardUnknown() {
- xxx_messageInfo_EventGrant.DiscardUnknown(m)
+func (m *EventGranted) XXX_DiscardUnknown() {
+ xxx_messageInfo_EventGranted.DiscardUnknown(m)
}
-var xxx_messageInfo_EventGrant proto.InternalMessageInfo
+var xxx_messageInfo_EventGranted proto.InternalMessageInfo
-func (m *EventGrant) GetContractId() string {
+func (m *EventGranted) GetContractId() string {
if m != nil {
return m.ContractId
}
return ""
}
-func (m *EventGrant) GetGranter() string {
+func (m *EventGranted) GetGranter() string {
if m != nil {
return m.Granter
}
return ""
}
-func (m *EventGrant) GetGrantee() string {
+func (m *EventGranted) GetGrantee() string {
if m != nil {
return m.Grantee
}
return ""
}
-func (m *EventGrant) GetPermission() Permission {
+func (m *EventGranted) GetPermission() Permission {
if m != nil {
return m.Permission
}
return PermissionUnspecified
}
-// EventAbandon is emitted when a grantee abandons its permission.
+// EventRenounced is emitted when a grantee renounces its permission.
//
// Since: 0.46.0 (finschia)
-type EventAbandon struct {
+type EventRenounced struct {
// contract id associated with the token class.
ContractId string `protobuf:"bytes,1,opt,name=contract_id,json=contractId,proto3" json:"contract_id,omitempty"`
// address of the grantee which abandons its grant.
@@ -546,18 +546,18 @@ type EventAbandon struct {
Permission Permission `protobuf:"varint,3,opt,name=permission,proto3,enum=lbm.token.v1.Permission" json:"permission,omitempty"`
}
-func (m *EventAbandon) Reset() { *m = EventAbandon{} }
-func (m *EventAbandon) String() string { return proto.CompactTextString(m) }
-func (*EventAbandon) ProtoMessage() {}
-func (*EventAbandon) Descriptor() ([]byte, []int) {
+func (m *EventRenounced) Reset() { *m = EventRenounced{} }
+func (m *EventRenounced) String() string { return proto.CompactTextString(m) }
+func (*EventRenounced) ProtoMessage() {}
+func (*EventRenounced) Descriptor() ([]byte, []int) {
return fileDescriptor_d7505f4c4cdec18e, []int{5}
}
-func (m *EventAbandon) XXX_Unmarshal(b []byte) error {
+func (m *EventRenounced) XXX_Unmarshal(b []byte) error {
return m.Unmarshal(b)
}
-func (m *EventAbandon) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
+func (m *EventRenounced) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
if deterministic {
- return xxx_messageInfo_EventAbandon.Marshal(b, m, deterministic)
+ return xxx_messageInfo_EventRenounced.Marshal(b, m, deterministic)
} else {
b = b[:cap(b)]
n, err := m.MarshalToSizedBuffer(b)
@@ -567,33 +567,33 @@ func (m *EventAbandon) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
return b[:n], nil
}
}
-func (m *EventAbandon) XXX_Merge(src proto.Message) {
- xxx_messageInfo_EventAbandon.Merge(m, src)
+func (m *EventRenounced) XXX_Merge(src proto.Message) {
+ xxx_messageInfo_EventRenounced.Merge(m, src)
}
-func (m *EventAbandon) XXX_Size() int {
+func (m *EventRenounced) XXX_Size() int {
return m.Size()
}
-func (m *EventAbandon) XXX_DiscardUnknown() {
- xxx_messageInfo_EventAbandon.DiscardUnknown(m)
+func (m *EventRenounced) XXX_DiscardUnknown() {
+ xxx_messageInfo_EventRenounced.DiscardUnknown(m)
}
-var xxx_messageInfo_EventAbandon proto.InternalMessageInfo
+var xxx_messageInfo_EventRenounced proto.InternalMessageInfo
-func (m *EventAbandon) GetContractId() string {
+func (m *EventRenounced) GetContractId() string {
if m != nil {
return m.ContractId
}
return ""
}
-func (m *EventAbandon) GetGrantee() string {
+func (m *EventRenounced) GetGrantee() string {
if m != nil {
return m.Grantee
}
return ""
}
-func (m *EventAbandon) GetPermission() Permission {
+func (m *EventRenounced) GetPermission() Permission {
if m != nil {
return m.Permission
}
@@ -808,9 +808,9 @@ func init() {
proto.RegisterType((*EventSent)(nil), "lbm.token.v1.EventSent")
proto.RegisterType((*EventAuthorizedOperator)(nil), "lbm.token.v1.EventAuthorizedOperator")
proto.RegisterType((*EventRevokedOperator)(nil), "lbm.token.v1.EventRevokedOperator")
- proto.RegisterType((*EventIssue)(nil), "lbm.token.v1.EventIssue")
- proto.RegisterType((*EventGrant)(nil), "lbm.token.v1.EventGrant")
- proto.RegisterType((*EventAbandon)(nil), "lbm.token.v1.EventAbandon")
+ proto.RegisterType((*EventIssued)(nil), "lbm.token.v1.EventIssued")
+ proto.RegisterType((*EventGranted)(nil), "lbm.token.v1.EventGranted")
+ proto.RegisterType((*EventRenounced)(nil), "lbm.token.v1.EventRenounced")
proto.RegisterType((*EventMinted)(nil), "lbm.token.v1.EventMinted")
proto.RegisterType((*EventBurned)(nil), "lbm.token.v1.EventBurned")
proto.RegisterType((*EventModified)(nil), "lbm.token.v1.EventModified")
@@ -819,78 +819,78 @@ func init() {
func init() { proto.RegisterFile("lbm/token/v1/event.proto", fileDescriptor_d7505f4c4cdec18e) }
var fileDescriptor_d7505f4c4cdec18e = []byte{
- // 1121 bytes of a gzipped FileDescriptorProto
- 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x56, 0x4f, 0x6f, 0xe3, 0xc4,
- 0x1b, 0x8e, 0x9b, 0x34, 0x49, 0xa7, 0xdd, 0xfe, 0xfc, 0xf3, 0xa6, 0xad, 0xd7, 0xa0, 0xd4, 0xf4,
- 0x54, 0x16, 0x36, 0x61, 0xff, 0x00, 0xbb, 0xdc, 0x9c, 0xc6, 0xad, 0xac, 0xd6, 0x76, 0x34, 0x71,
- 0x0a, 0xe5, 0x12, 0x39, 0xc9, 0x34, 0xb5, 0x1a, 0x7b, 0x22, 0xdb, 0x29, 0x1b, 0x4e, 0x48, 0x5c,
- 0x50, 0xc4, 0x81, 0x3b, 0xf2, 0x01, 0xc1, 0x81, 0x1b, 0x5f, 0x63, 0x8f, 0xcb, 0x01, 0x09, 0x71,
- 0x58, 0xa1, 0xf6, 0x8b, 0xa0, 0x19, 0xc7, 0xae, 0x1d, 0x17, 0xc1, 0x52, 0xb8, 0xcd, 0xeb, 0x79,
- 0x9e, 0x99, 0xe7, 0x9d, 0xf7, 0x79, 0x67, 0x0c, 0xf8, 0x51, 0xcf, 0xae, 0xfb, 0xf8, 0x1c, 0x39,
- 0xf5, 0x8b, 0x87, 0x75, 0x74, 0x81, 0x1c, 0xbf, 0x36, 0x76, 0xb1, 0x8f, 0xb9, 0xb5, 0x51, 0xcf,
- 0xae, 0xd1, 0x99, 0xda, 0xc5, 0x43, 0xa1, 0x32, 0xc4, 0x43, 0x4c, 0x27, 0xea, 0x64, 0x14, 0x62,
- 0x84, 0x34, 0x3b, 0x04, 0xd3, 0x99, 0x9d, 0x9f, 0x18, 0xb0, 0x22, 0x93, 0xd5, 0xda, 0xc8, 0xf1,
- 0xb9, 0x6d, 0xb0, 0xda, 0xc7, 0x8e, 0xef, 0x9a, 0x7d, 0xbf, 0x6b, 0x0d, 0x78, 0x46, 0x64, 0x76,
- 0x57, 0x20, 0x88, 0x3e, 0x29, 0x03, 0x4e, 0x00, 0x65, 0x3c, 0x46, 0xae, 0xe9, 0x63, 0x97, 0x5f,
- 0xa2, 0xb3, 0x71, 0xcc, 0x71, 0xa0, 0x70, 0xea, 0x62, 0x9b, 0xcf, 0xd3, 0xef, 0x74, 0xcc, 0xad,
- 0x83, 0x25, 0x1f, 0xf3, 0x05, 0xfa, 0x65, 0xc9, 0xc7, 0x9c, 0x04, 0x8a, 0xa6, 0x8d, 0x27, 0x8e,
- 0xcf, 0x2f, 0x93, 0x6f, 0x8d, 0xb7, 0x5f, 0xbc, 0xda, 0xce, 0xfd, 0xf6, 0x6a, 0xfb, 0xad, 0xa1,
- 0xe5, 0x9f, 0x4d, 0x7a, 0xb5, 0x3e, 0xb6, 0xeb, 0x23, 0xcb, 0x41, 0xf5, 0x51, 0xcf, 0x7e, 0xe0,
- 0x0d, 0xce, 0xeb, 0xfe, 0x74, 0x8c, 0xbc, 0x9a, 0xe2, 0xf8, 0x70, 0x4e, 0xdc, 0x71, 0xc0, 0x16,
- 0x15, 0x2c, 0x4d, 0xfc, 0x33, 0xec, 0x5a, 0x9f, 0xa3, 0x81, 0x1e, 0x29, 0xf8, 0x4b, 0xf9, 0x9b,
- 0xa0, 0x78, 0x86, 0x47, 0x03, 0x14, 0x89, 0x9f, 0x47, 0xa9, 0xb4, 0xf2, 0xe9, 0xb4, 0x76, 0xce,
- 0x41, 0x85, 0xee, 0x07, 0xd1, 0x05, 0x3e, 0xff, 0xaf, 0x37, 0xfb, 0x99, 0x01, 0x80, 0xee, 0xa6,
- 0x78, 0xde, 0x04, 0x71, 0x3c, 0x28, 0xf5, 0x5d, 0x44, 0x91, 0xe1, 0xfa, 0x51, 0xb8, 0xb8, 0xfb,
- 0x52, 0x66, 0x77, 0x0e, 0x14, 0x1c, 0xd3, 0x46, 0x51, 0x35, 0xc8, 0x98, 0x28, 0xf2, 0xa6, 0x76,
- 0x0f, 0x8f, 0xe6, 0x15, 0x99, 0x47, 0x1c, 0x0b, 0xf2, 0x13, 0xd7, 0x0a, 0x4b, 0x02, 0xc9, 0x90,
- 0xb0, 0x6d, 0xe4, 0x9b, 0x7c, 0x31, 0x64, 0x93, 0x31, 0xd1, 0x3d, 0x40, 0x7d, 0xcb, 0x36, 0x47,
- 0x1e, 0x5f, 0x12, 0x99, 0xdd, 0x65, 0x18, 0xc7, 0x64, 0xce, 0xb6, 0x1c, 0xdf, 0xec, 0x8d, 0x10,
- 0x5f, 0x16, 0x99, 0xdd, 0x32, 0x8c, 0xe3, 0x9d, 0x6f, 0xa3, 0x9c, 0x0e, 0x5c, 0xf3, 0xef, 0x78,
- 0x8c, 0x07, 0xa5, 0x21, 0x41, 0xc6, 0x07, 0x17, 0x85, 0xd7, 0x33, 0x51, 0x5a, 0x51, 0xc8, 0x3d,
- 0x05, 0x60, 0x8c, 0x5c, 0xdb, 0xf2, 0x3c, 0x0b, 0x3b, 0x34, 0xbb, 0xf5, 0x47, 0x7c, 0x2d, 0xd9,
- 0x19, 0xb5, 0x56, 0x3c, 0x0f, 0x13, 0xd8, 0x9d, 0x2f, 0x19, 0xb0, 0x16, 0xfa, 0xa9, 0x67, 0x3a,
- 0x03, 0xec, 0xbc, 0x86, 0x3e, 0x94, 0xd6, 0xb7, 0xa8, 0x22, 0xff, 0x1a, 0x2a, 0x02, 0x06, 0xac,
- 0x52, 0x15, 0xaa, 0xe5, 0xf8, 0x68, 0x70, 0xbb, 0x46, 0x0c, 0x9b, 0x2e, 0x7f, 0x43, 0xd3, 0x15,
- 0xfe, 0x69, 0xd3, 0x7d, 0x17, 0xe9, 0x6b, 0x4c, 0x5c, 0xe7, 0xb6, 0xfa, 0x6e, 0xba, 0x28, 0xfe,
- 0x05, 0x8d, 0x5f, 0x30, 0xe0, 0x4e, 0x78, 0x86, 0x78, 0x60, 0x9d, 0x5a, 0xb7, 0x55, 0xf9, 0x08,
- 0x94, 0xfa, 0x67, 0xa6, 0x33, 0x44, 0x1e, 0x9f, 0x17, 0xf3, 0xbb, 0xab, 0x8f, 0xb8, 0x85, 0x4a,
- 0x9a, 0x96, 0xdb, 0x28, 0x10, 0x99, 0x30, 0x02, 0xde, 0xff, 0xa5, 0x30, 0xbf, 0x4d, 0x8d, 0xe9,
- 0x18, 0x71, 0x4f, 0xc0, 0xa6, 0x7c, 0x2c, 0x6b, 0x46, 0xd7, 0x38, 0x69, 0xc9, 0xdd, 0x8e, 0xd6,
- 0x6e, 0xc9, 0x7b, 0xca, 0xbe, 0x22, 0x37, 0xd9, 0x9c, 0xc0, 0xcf, 0x02, 0xb1, 0x12, 0x43, 0x3b,
- 0x8e, 0x37, 0x46, 0xfd, 0x50, 0xf4, 0x03, 0xc0, 0x26, 0x58, 0x4a, 0xbb, 0xdd, 0x91, 0x59, 0x46,
- 0xd8, 0x9a, 0x05, 0xe2, 0xdd, 0x18, 0x4f, 0x6f, 0x07, 0x83, 0x28, 0xe1, 0xde, 0x01, 0xff, 0x4b,
- 0xc0, 0x55, 0x45, 0x33, 0xd8, 0x25, 0x61, 0x73, 0x16, 0x88, 0x5c, 0x8c, 0x26, 0x9e, 0xba, 0x09,
- 0xdc, 0xe8, 0x40, 0x8d, 0xcd, 0x2f, 0x80, 0x49, 0x81, 0x43, 0xf0, 0x13, 0x50, 0x59, 0x00, 0x77,
- 0xf7, 0xa1, 0xae, 0xb2, 0x05, 0x41, 0x98, 0x05, 0xe2, 0x66, 0x96, 0xb1, 0x4f, 0x0a, 0xf9, 0x3e,
- 0xd8, 0x4a, 0xea, 0xd1, 0x9b, 0xca, 0xfe, 0x49, 0xd7, 0xd0, 0x0f, 0x65, 0x8d, 0x5d, 0x5e, 0xc8,
- 0x9a, 0xd6, 0x69, 0x1a, 0x6e, 0x56, 0x03, 0x77, 0x13, 0x34, 0x03, 0x4a, 0x5a, 0x7b, 0x5f, 0x86,
- 0x6c, 0x51, 0xd8, 0x98, 0x05, 0xe2, 0xff, 0x63, 0x8a, 0xe1, 0x9a, 0x8e, 0x77, 0x8a, 0x5c, 0xee,
- 0x43, 0xc0, 0xdf, 0x80, 0x0f, 0x05, 0x96, 0x84, 0x7b, 0xb3, 0x40, 0xdc, 0xc8, 0x90, 0xa8, 0xbe,
- 0x0f, 0xc0, 0x46, 0x82, 0x78, 0x00, 0x25, 0xcd, 0xe8, 0xb6, 0x64, 0xa8, 0xb2, 0x65, 0xe1, 0x8d,
- 0x59, 0x20, 0x6e, 0xc5, 0x2c, 0x7a, 0x5b, 0x91, 0x76, 0x0d, 0x05, 0x3e, 0x4d, 0x15, 0x13, 0xca,
- 0xc7, 0xfa, 0xa1, 0x1c, 0x12, 0x57, 0x84, 0x37, 0x67, 0x81, 0xc8, 0xc7, 0xc4, 0xf0, 0xa1, 0xb8,
- 0x66, 0xa6, 0xa5, 0x4a, 0xad, 0x16, 0xd4, 0x8f, 0xe5, 0xf9, 0x91, 0x80, 0x05, 0xa9, 0xd2, 0x78,
- 0xec, 0xe2, 0x8b, 0xb0, 0xb4, 0x42, 0xf9, 0xab, 0xef, 0xab, 0xb9, 0x1f, 0x7f, 0xa8, 0xe6, 0xee,
- 0x7f, 0x5d, 0x04, 0x6b, 0x92, 0xef, 0xbb, 0x56, 0x6f, 0xe2, 0xa3, 0x43, 0x34, 0xe5, 0x3e, 0x02,
- 0xf7, 0x24, 0xc3, 0x80, 0x4a, 0xa3, 0x63, 0xc8, 0xdd, 0x43, 0xf9, 0x64, 0xc1, 0x5d, 0x34, 0x93,
- 0x24, 0x21, 0x69, 0xb0, 0x77, 0x01, 0x97, 0xe6, 0x6a, 0x92, 0x4a, 0x2c, 0x56, 0x99, 0x05, 0x22,
- 0x9b, 0x24, 0x69, 0xe4, 0xcd, 0x78, 0x0f, 0x54, 0xd2, 0xe8, 0xf6, 0x89, 0xda, 0xd0, 0x8f, 0x22,
- 0x93, 0x25, 0xf1, 0xed, 0xf0, 0x35, 0xc9, 0xac, 0xaf, 0xca, 0x86, 0xc4, 0xe6, 0xb3, 0xeb, 0xab,
- 0xe4, 0x55, 0x79, 0xb6, 0x98, 0xc9, 0x9e, 0xae, 0x19, 0x50, 0xda, 0x33, 0xba, 0x4a, 0x33, 0xb2,
- 0x5a, 0x92, 0xb4, 0x17, 0x75, 0x6f, 0x93, 0x78, 0x26, 0x4d, 0xd5, 0x3f, 0xd6, 0x64, 0xc8, 0x2e,
- 0x87, 0x9e, 0x49, 0x92, 0xf4, 0xcf, 0x1c, 0xe4, 0x66, 0x53, 0x91, 0x54, 0xbd, 0xa3, 0x19, 0x6c,
- 0x31, 0x9b, 0x8a, 0x44, 0xaf, 0x14, 0xd2, 0xc1, 0x69, 0x46, 0x53, 0xde, 0x53, 0x54, 0xe9, 0xa8,
- 0xcd, 0x96, 0x42, 0x2f, 0x27, 0x39, 0xcd, 0xe8, 0x31, 0x7c, 0x0c, 0x36, 0xd2, 0x2c, 0x45, 0x3d,
- 0xe8, 0x76, 0xa0, 0xc2, 0x96, 0xb3, 0x24, 0xc5, 0x36, 0x87, 0xa8, 0x03, 0x95, 0xec, 0x56, 0xa4,
- 0x95, 0xa5, 0xc6, 0x91, 0xcc, 0xae, 0x64, 0x59, 0xea, 0xfc, 0x6d, 0xcd, 0x9e, 0x35, 0x6d, 0x00,
- 0x90, 0x3d, 0x6b, 0xea, 0xfd, 0x5d, 0xc0, 0xa6, 0xd1, 0x86, 0xce, 0xae, 0x0a, 0xdc, 0x2c, 0x10,
- 0xd7, 0x93, 0x58, 0x03, 0x67, 0xd7, 0xa5, 0x4e, 0x5f, 0xcb, 0xae, 0x4b, 0x6c, 0x9e, 0xd5, 0x3e,
- 0x37, 0x39, 0x64, 0xef, 0x64, 0xb5, 0xcf, 0x2d, 0xee, 0x66, 0xcb, 0xd7, 0x82, 0xfa, 0x27, 0x27,
- 0xec, 0x7a, 0xb6, 0x7c, 0x2d, 0x17, 0x3f, 0x9f, 0x5e, 0xb7, 0x43, 0xe3, 0xd9, 0x8b, 0xcb, 0x2a,
- 0xf3, 0xf2, 0xb2, 0xca, 0xfc, 0x7e, 0x59, 0x65, 0xbe, 0xb9, 0xaa, 0xe6, 0x5e, 0x5e, 0x55, 0x73,
- 0xbf, 0x5e, 0x55, 0x73, 0x9f, 0x6e, 0xff, 0xd9, 0x73, 0xf1, 0x3c, 0xfc, 0xeb, 0xed, 0x15, 0xe9,
- 0x6f, 0xef, 0xe3, 0x3f, 0x02, 0x00, 0x00, 0xff, 0xff, 0x06, 0x5b, 0x91, 0x8d, 0x50, 0x0b, 0x00,
- 0x00,
+ // 1124 bytes of a gzipped FileDescriptorProto
+ 0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x56, 0x4f, 0x6f, 0xe3, 0x44,
+ 0x14, 0x8f, 0x9b, 0x34, 0x49, 0xa7, 0xdd, 0x32, 0x78, 0xd3, 0xd6, 0x6b, 0x50, 0x6a, 0x7a, 0x2a,
+ 0x0b, 0x9b, 0xb0, 0x7f, 0x80, 0x5d, 0x6e, 0x4e, 0xe3, 0x56, 0x56, 0x6b, 0x3b, 0x9a, 0x38, 0x85,
+ 0x72, 0x89, 0x9c, 0x64, 0x9a, 0x5a, 0x8d, 0x3d, 0x91, 0xe3, 0x94, 0x0d, 0x27, 0x2e, 0x48, 0x28,
+ 0xe2, 0xc0, 0x17, 0xf0, 0x01, 0xc1, 0x81, 0x1b, 0x5f, 0x63, 0x8f, 0x2b, 0x24, 0x24, 0xc4, 0x61,
+ 0x85, 0xda, 0x2f, 0x82, 0x66, 0x1c, 0xa7, 0x76, 0x5c, 0x58, 0x96, 0x85, 0xdb, 0x3c, 0xcf, 0xef,
+ 0x37, 0xef, 0xf7, 0xe6, 0xbd, 0x37, 0xcf, 0x40, 0x18, 0x74, 0x9c, 0xaa, 0x4f, 0xce, 0xb1, 0x5b,
+ 0xbd, 0xb8, 0x5f, 0xc5, 0x17, 0xd8, 0xf5, 0x2b, 0x43, 0x8f, 0xf8, 0x84, 0x5f, 0x1b, 0x74, 0x9c,
+ 0x0a, 0xdb, 0xa9, 0x5c, 0xdc, 0x17, 0x4b, 0x7d, 0xd2, 0x27, 0x6c, 0xa3, 0x4a, 0x57, 0x21, 0x46,
+ 0x4c, 0xb2, 0x43, 0x30, 0xdb, 0xd9, 0xf9, 0x99, 0x03, 0x2b, 0x0a, 0x3d, 0xad, 0x89, 0x5d, 0x9f,
+ 0xdf, 0x06, 0xab, 0x5d, 0xe2, 0xfa, 0x9e, 0xd5, 0xf5, 0xdb, 0x76, 0x4f, 0xe0, 0x24, 0x6e, 0x77,
+ 0x05, 0x81, 0xe8, 0x93, 0xda, 0xe3, 0x45, 0x50, 0x24, 0x43, 0xec, 0x59, 0x3e, 0xf1, 0x84, 0x25,
+ 0xb6, 0x3b, 0xb7, 0x79, 0x1e, 0xe4, 0x4e, 0x3d, 0xe2, 0x08, 0x59, 0xf6, 0x9d, 0xad, 0xf9, 0x75,
+ 0xb0, 0xe4, 0x13, 0x21, 0xc7, 0xbe, 0x2c, 0xf9, 0x84, 0x97, 0x41, 0xde, 0x72, 0xc8, 0xd8, 0xf5,
+ 0x85, 0x65, 0xfa, 0xad, 0xf6, 0xee, 0xb3, 0x17, 0xdb, 0x99, 0xdf, 0x5f, 0x6c, 0xbf, 0xd3, 0xb7,
+ 0xfd, 0xb3, 0x71, 0xa7, 0xd2, 0x25, 0x4e, 0x75, 0x60, 0xbb, 0xb8, 0x3a, 0xe8, 0x38, 0xf7, 0x46,
+ 0xbd, 0xf3, 0xaa, 0x3f, 0x19, 0xe2, 0x51, 0x45, 0x75, 0x7d, 0x34, 0x23, 0xee, 0xb8, 0x60, 0x8b,
+ 0x09, 0x96, 0xc7, 0xfe, 0x19, 0xf1, 0xec, 0x2f, 0x71, 0xcf, 0x88, 0x14, 0xbc, 0x54, 0xfe, 0x26,
+ 0xc8, 0x9f, 0x91, 0x41, 0x0f, 0x47, 0xe2, 0x67, 0x56, 0x22, 0xac, 0x6c, 0x32, 0xac, 0x9d, 0x73,
+ 0x50, 0x62, 0xfe, 0x10, 0xbe, 0x20, 0xe7, 0xff, 0xb7, 0xb3, 0x5f, 0x38, 0xb0, 0xca, 0xbc, 0xa9,
+ 0xa3, 0xd1, 0x18, 0xf7, 0x78, 0x01, 0x14, 0xba, 0x1e, 0x66, 0xd0, 0xd0, 0x41, 0x64, 0x2e, 0xba,
+ 0x5f, 0x4a, 0xb9, 0xe7, 0x41, 0xce, 0xb5, 0x1c, 0x1c, 0xa5, 0x83, 0xae, 0xa9, 0xa4, 0xd1, 0xc4,
+ 0xe9, 0x90, 0xc1, 0x2c, 0x25, 0x33, 0x8b, 0x87, 0x20, 0x3b, 0xf6, 0xec, 0x30, 0x27, 0x88, 0x2e,
+ 0x29, 0xdb, 0xc1, 0xbe, 0x25, 0xe4, 0x43, 0x36, 0x5d, 0x53, 0xe1, 0x3d, 0xdc, 0xb5, 0x1d, 0x6b,
+ 0x30, 0x12, 0x0a, 0x12, 0xb7, 0xbb, 0x8c, 0xe6, 0x36, 0xdd, 0x73, 0x6c, 0xd7, 0xb7, 0x3a, 0x03,
+ 0x2c, 0x14, 0x25, 0x6e, 0xb7, 0x88, 0xe6, 0xf6, 0x4e, 0xc0, 0x81, 0x35, 0x16, 0xd4, 0x81, 0x67,
+ 0xb9, 0x3e, 0xee, 0xbd, 0xfc, 0xea, 0x04, 0x50, 0xe8, 0x33, 0x6c, 0x74, 0x77, 0x91, 0x79, 0xbd,
+ 0x13, 0x05, 0x16, 0x99, 0xfc, 0x63, 0x00, 0x86, 0xd8, 0x73, 0xec, 0xd1, 0xc8, 0x26, 0x2e, 0x8b,
+ 0x6f, 0xfd, 0x81, 0x50, 0x89, 0x37, 0x47, 0xa5, 0x31, 0xdf, 0x47, 0x31, 0xec, 0xce, 0xd7, 0x1c,
+ 0x58, 0x9f, 0xa5, 0xd8, 0x25, 0x63, 0xb7, 0xfb, 0x4a, 0x0a, 0x71, 0x52, 0xe1, 0xa2, 0x8e, 0xec,
+ 0x2b, 0xe8, 0x08, 0xa2, 0xe4, 0x6b, 0xf6, 0x3f, 0xbb, 0xa6, 0xbf, 0xeb, 0xc6, 0xb0, 0xf3, 0xb2,
+ 0x37, 0x74, 0x5e, 0xee, 0xdf, 0x76, 0xde, 0xf7, 0x91, 0xbe, 0xda, 0xd8, 0x73, 0x5f, 0x57, 0xdf,
+ 0x4d, 0xaf, 0xc5, 0x7f, 0xa0, 0xf1, 0x2b, 0x0e, 0xdc, 0x0a, 0xef, 0x90, 0xf4, 0xec, 0x53, 0xfb,
+ 0x75, 0x55, 0x3e, 0x00, 0x85, 0xee, 0x99, 0xe5, 0xf6, 0xf1, 0x48, 0xc8, 0x4a, 0xd9, 0xdd, 0xd5,
+ 0x07, 0xfc, 0x42, 0x26, 0x2d, 0xdb, 0xab, 0xe5, 0xa8, 0x4c, 0x14, 0x01, 0xef, 0xfe, 0x9a, 0x9b,
+ 0x3d, 0xa9, 0xe6, 0x64, 0x88, 0xf9, 0x47, 0x60, 0x53, 0x39, 0x56, 0x74, 0xb3, 0x6d, 0x9e, 0x34,
+ 0x94, 0x76, 0x4b, 0x6f, 0x36, 0x94, 0x3d, 0x75, 0x5f, 0x55, 0xea, 0x30, 0x23, 0x0a, 0xd3, 0x40,
+ 0x2a, 0xcd, 0xa1, 0x2d, 0x77, 0x34, 0xc4, 0xdd, 0x50, 0xf4, 0x3d, 0x00, 0x63, 0x2c, 0xb5, 0xd9,
+ 0x6c, 0x29, 0x90, 0x13, 0xb7, 0xa6, 0x81, 0x74, 0x7b, 0x8e, 0x67, 0x4f, 0x84, 0x49, 0x95, 0xf0,
+ 0xef, 0x81, 0x37, 0x62, 0x70, 0x4d, 0xd5, 0x4d, 0xb8, 0x24, 0x6e, 0x4e, 0x03, 0x89, 0x9f, 0xa3,
+ 0x69, 0x4d, 0xdd, 0x04, 0xae, 0xb5, 0x90, 0x0e, 0xb3, 0x0b, 0x60, 0x9a, 0xe0, 0x10, 0xfc, 0x08,
+ 0x94, 0x16, 0xc0, 0xed, 0x7d, 0x64, 0x68, 0x30, 0x27, 0x8a, 0xd3, 0x40, 0xda, 0x4c, 0x33, 0xf6,
+ 0x69, 0x22, 0x3f, 0x04, 0x5b, 0x71, 0x3d, 0x46, 0x5d, 0xdd, 0x3f, 0x69, 0x9b, 0xc6, 0xa1, 0xa2,
+ 0xc3, 0xe5, 0x85, 0xa8, 0x59, 0x9e, 0x26, 0xa1, 0xb3, 0x0a, 0xb8, 0x1d, 0xa3, 0x99, 0x48, 0xd6,
+ 0x9b, 0xfb, 0x0a, 0x82, 0x79, 0x71, 0x63, 0x1a, 0x48, 0x6f, 0xce, 0x29, 0xa6, 0x67, 0xb9, 0xa3,
+ 0x53, 0xec, 0xf1, 0x1f, 0x03, 0xe1, 0x06, 0x7c, 0x28, 0xb0, 0x20, 0xde, 0x99, 0x06, 0xd2, 0x46,
+ 0x8a, 0xc4, 0xf4, 0x7d, 0x04, 0x36, 0x62, 0xc4, 0x03, 0x24, 0xeb, 0x66, 0xbb, 0xa1, 0x20, 0x0d,
+ 0x16, 0xc5, 0xb7, 0xa6, 0x81, 0xb4, 0x35, 0x67, 0xb1, 0x17, 0x8b, 0xb6, 0x6b, 0x28, 0xf0, 0x71,
+ 0x22, 0x99, 0x48, 0x39, 0x36, 0x0e, 0x95, 0x90, 0xb8, 0x22, 0xbe, 0x3d, 0x0d, 0x24, 0x61, 0x4e,
+ 0x0c, 0xa7, 0xc5, 0x35, 0x33, 0x29, 0x55, 0x6e, 0x34, 0x90, 0x71, 0xac, 0xcc, 0xae, 0x04, 0x2c,
+ 0x48, 0x95, 0x87, 0x43, 0x8f, 0x5c, 0x84, 0xa9, 0x15, 0x8b, 0xdf, 0xfc, 0x50, 0xce, 0xfc, 0xf4,
+ 0x63, 0x39, 0x73, 0xf7, 0xdb, 0x3c, 0x58, 0x93, 0x7d, 0xdf, 0xb3, 0x3b, 0x63, 0x1f, 0x1f, 0xe2,
+ 0x09, 0xff, 0x09, 0xb8, 0x23, 0x9b, 0x26, 0x52, 0x6b, 0x2d, 0x53, 0x69, 0x1f, 0x2a, 0x27, 0x0b,
+ 0xd5, 0xc5, 0x22, 0x89, 0x13, 0xe2, 0x05, 0xf6, 0x3e, 0xe0, 0x93, 0x5c, 0x5d, 0xd6, 0x68, 0x89,
+ 0x95, 0xa6, 0x81, 0x04, 0xe3, 0x24, 0x9d, 0xce, 0x8d, 0x0f, 0x40, 0x29, 0x89, 0x6e, 0x9e, 0x68,
+ 0x35, 0xe3, 0x28, 0x2a, 0xb2, 0x38, 0xbe, 0x19, 0x4e, 0x94, 0xd4, 0xf9, 0x9a, 0x62, 0xca, 0x30,
+ 0x9b, 0x3e, 0x5f, 0xa3, 0x93, 0xe5, 0xc9, 0x62, 0x24, 0x7b, 0x86, 0x6e, 0x22, 0x79, 0xcf, 0x6c,
+ 0xab, 0xf5, 0xa8, 0xd4, 0xe2, 0xa4, 0xbd, 0xa8, 0x7b, 0xeb, 0xb4, 0x66, 0x92, 0x54, 0xe3, 0x53,
+ 0x5d, 0x41, 0x70, 0x39, 0xac, 0x99, 0x38, 0xc9, 0xf8, 0xc2, 0xc5, 0x5e, 0x3a, 0x14, 0x59, 0x33,
+ 0x5a, 0xba, 0x09, 0xf3, 0xe9, 0x50, 0x64, 0xf6, 0xa4, 0xd0, 0x0e, 0x4e, 0x32, 0xea, 0xca, 0x9e,
+ 0xaa, 0xc9, 0x47, 0x4d, 0x58, 0x08, 0x6b, 0x39, 0xce, 0xa9, 0x47, 0x03, 0xf1, 0x21, 0xd8, 0x48,
+ 0xb2, 0x54, 0xed, 0xa0, 0xdd, 0x42, 0x2a, 0x2c, 0xa6, 0x49, 0xaa, 0x63, 0xf5, 0x71, 0x0b, 0xa9,
+ 0x69, 0x57, 0xb4, 0x95, 0xe5, 0xda, 0x91, 0x02, 0x57, 0xd2, 0x2c, 0x6d, 0x36, 0x5f, 0xd3, 0x77,
+ 0xcd, 0x1a, 0x00, 0xa4, 0xef, 0x9a, 0xd5, 0xfe, 0x2e, 0x80, 0x49, 0xb4, 0x69, 0xc0, 0x55, 0x91,
+ 0x9f, 0x06, 0xd2, 0x7a, 0x1c, 0x6b, 0x92, 0xf4, 0xb9, 0xac, 0xd2, 0xd7, 0xd2, 0xe7, 0xd2, 0x32,
+ 0x4f, 0x6b, 0x9f, 0x15, 0x39, 0x82, 0xb7, 0xd2, 0xda, 0x67, 0x25, 0xee, 0xa5, 0xd3, 0xd7, 0x40,
+ 0xc6, 0x67, 0x27, 0x70, 0x3d, 0x9d, 0xbe, 0x86, 0x47, 0x9e, 0x4e, 0xae, 0xdb, 0xa1, 0xf6, 0xe4,
+ 0xd9, 0x65, 0x99, 0x7b, 0x7e, 0x59, 0xe6, 0xfe, 0xb8, 0x2c, 0x73, 0xdf, 0x5d, 0x95, 0x33, 0xcf,
+ 0xaf, 0xca, 0x99, 0xdf, 0xae, 0xca, 0x99, 0xcf, 0xb7, 0xff, 0x6a, 0x5c, 0x3c, 0x0d, 0x7f, 0x7d,
+ 0x3b, 0x79, 0xf6, 0xef, 0xfb, 0xf0, 0xcf, 0x00, 0x00, 0x00, 0xff, 0xff, 0x09, 0xc6, 0xf1, 0x28,
+ 0x55, 0x0b, 0x00, 0x00,
}
func (m *EventSent) Marshal() (dAtA []byte, err error) {
@@ -1042,7 +1042,7 @@ func (m *EventRevokedOperator) MarshalToSizedBuffer(dAtA []byte) (int, error) {
return len(dAtA) - i, nil
}
-func (m *EventIssue) Marshal() (dAtA []byte, err error) {
+func (m *EventIssued) Marshal() (dAtA []byte, err error) {
size := m.Size()
dAtA = make([]byte, size)
n, err := m.MarshalToSizedBuffer(dAtA[:size])
@@ -1052,12 +1052,12 @@ func (m *EventIssue) Marshal() (dAtA []byte, err error) {
return dAtA[:n], nil
}
-func (m *EventIssue) MarshalTo(dAtA []byte) (int, error) {
+func (m *EventIssued) MarshalTo(dAtA []byte) (int, error) {
size := m.Size()
return m.MarshalToSizedBuffer(dAtA[:size])
}
-func (m *EventIssue) MarshalToSizedBuffer(dAtA []byte) (int, error) {
+func (m *EventIssued) MarshalToSizedBuffer(dAtA []byte) (int, error) {
i := len(dAtA)
_ = i
var l int
@@ -1122,7 +1122,7 @@ func (m *EventIssue) MarshalToSizedBuffer(dAtA []byte) (int, error) {
return len(dAtA) - i, nil
}
-func (m *EventGrant) Marshal() (dAtA []byte, err error) {
+func (m *EventGranted) Marshal() (dAtA []byte, err error) {
size := m.Size()
dAtA = make([]byte, size)
n, err := m.MarshalToSizedBuffer(dAtA[:size])
@@ -1132,12 +1132,12 @@ func (m *EventGrant) Marshal() (dAtA []byte, err error) {
return dAtA[:n], nil
}
-func (m *EventGrant) MarshalTo(dAtA []byte) (int, error) {
+func (m *EventGranted) MarshalTo(dAtA []byte) (int, error) {
size := m.Size()
return m.MarshalToSizedBuffer(dAtA[:size])
}
-func (m *EventGrant) MarshalToSizedBuffer(dAtA []byte) (int, error) {
+func (m *EventGranted) MarshalToSizedBuffer(dAtA []byte) (int, error) {
i := len(dAtA)
_ = i
var l int
@@ -1171,7 +1171,7 @@ func (m *EventGrant) MarshalToSizedBuffer(dAtA []byte) (int, error) {
return len(dAtA) - i, nil
}
-func (m *EventAbandon) Marshal() (dAtA []byte, err error) {
+func (m *EventRenounced) Marshal() (dAtA []byte, err error) {
size := m.Size()
dAtA = make([]byte, size)
n, err := m.MarshalToSizedBuffer(dAtA[:size])
@@ -1181,12 +1181,12 @@ func (m *EventAbandon) Marshal() (dAtA []byte, err error) {
return dAtA[:n], nil
}
-func (m *EventAbandon) MarshalTo(dAtA []byte) (int, error) {
+func (m *EventRenounced) MarshalTo(dAtA []byte) (int, error) {
size := m.Size()
return m.MarshalToSizedBuffer(dAtA[:size])
}
-func (m *EventAbandon) MarshalToSizedBuffer(dAtA []byte) (int, error) {
+func (m *EventRenounced) MarshalToSizedBuffer(dAtA []byte) (int, error) {
i := len(dAtA)
_ = i
var l int
@@ -1452,7 +1452,7 @@ func (m *EventRevokedOperator) Size() (n int) {
return n
}
-func (m *EventIssue) Size() (n int) {
+func (m *EventIssued) Size() (n int) {
if m == nil {
return 0
}
@@ -1491,7 +1491,7 @@ func (m *EventIssue) Size() (n int) {
return n
}
-func (m *EventGrant) Size() (n int) {
+func (m *EventGranted) Size() (n int) {
if m == nil {
return 0
}
@@ -1515,7 +1515,7 @@ func (m *EventGrant) Size() (n int) {
return n
}
-func (m *EventAbandon) Size() (n int) {
+func (m *EventRenounced) Size() (n int) {
if m == nil {
return 0
}
@@ -2114,7 +2114,7 @@ func (m *EventRevokedOperator) Unmarshal(dAtA []byte) error {
}
return nil
}
-func (m *EventIssue) Unmarshal(dAtA []byte) error {
+func (m *EventIssued) Unmarshal(dAtA []byte) error {
l := len(dAtA)
iNdEx := 0
for iNdEx < l {
@@ -2137,10 +2137,10 @@ func (m *EventIssue) Unmarshal(dAtA []byte) error {
fieldNum := int32(wire >> 3)
wireType := int(wire & 0x7)
if wireType == 4 {
- return fmt.Errorf("proto: EventIssue: wiretype end group for non-group")
+ return fmt.Errorf("proto: EventIssued: wiretype end group for non-group")
}
if fieldNum <= 0 {
- return fmt.Errorf("proto: EventIssue: illegal tag %d (wire type %d)", fieldNum, wire)
+ return fmt.Errorf("proto: EventIssued: illegal tag %d (wire type %d)", fieldNum, wire)
}
switch fieldNum {
case 1:
@@ -2395,7 +2395,7 @@ func (m *EventIssue) Unmarshal(dAtA []byte) error {
}
return nil
}
-func (m *EventGrant) Unmarshal(dAtA []byte) error {
+func (m *EventGranted) Unmarshal(dAtA []byte) error {
l := len(dAtA)
iNdEx := 0
for iNdEx < l {
@@ -2418,10 +2418,10 @@ func (m *EventGrant) Unmarshal(dAtA []byte) error {
fieldNum := int32(wire >> 3)
wireType := int(wire & 0x7)
if wireType == 4 {
- return fmt.Errorf("proto: EventGrant: wiretype end group for non-group")
+ return fmt.Errorf("proto: EventGranted: wiretype end group for non-group")
}
if fieldNum <= 0 {
- return fmt.Errorf("proto: EventGrant: illegal tag %d (wire type %d)", fieldNum, wire)
+ return fmt.Errorf("proto: EventGranted: illegal tag %d (wire type %d)", fieldNum, wire)
}
switch fieldNum {
case 1:
@@ -2560,7 +2560,7 @@ func (m *EventGrant) Unmarshal(dAtA []byte) error {
}
return nil
}
-func (m *EventAbandon) Unmarshal(dAtA []byte) error {
+func (m *EventRenounced) Unmarshal(dAtA []byte) error {
l := len(dAtA)
iNdEx := 0
for iNdEx < l {
@@ -2583,10 +2583,10 @@ func (m *EventAbandon) Unmarshal(dAtA []byte) error {
fieldNum := int32(wire >> 3)
wireType := int(wire & 0x7)
if wireType == 4 {
- return fmt.Errorf("proto: EventAbandon: wiretype end group for non-group")
+ return fmt.Errorf("proto: EventRenounced: wiretype end group for non-group")
}
if fieldNum <= 0 {
- return fmt.Errorf("proto: EventAbandon: illegal tag %d (wire type %d)", fieldNum, wire)
+ return fmt.Errorf("proto: EventRenounced: illegal tag %d (wire type %d)", fieldNum, wire)
}
switch fieldNum {
case 1:
diff --git a/x/token/event_test.go b/x/token/event_test.go
index 85ba1dbb7f..dca71ad978 100644
--- a/x/token/event_test.go
+++ b/x/token/event_test.go
@@ -50,7 +50,7 @@ func TestNewEventIssueToken(t *testing.T) {
rand.Seed(time.Now().UnixNano())
str := func() string { return randomString(8) }
- event := token.EventIssue{
+ event := token.EventIssued{
Creator: str(),
ContractId: str(),
Name: str(),
@@ -257,7 +257,7 @@ func TestNewEventGrantPermToken(t *testing.T) {
return token.Permission(1 + rand.Intn(n))
}
- event := token.EventGrant{
+ event := token.EventGranted{
ContractId: str(),
Granter: str(),
Grantee: str(),
@@ -286,7 +286,7 @@ func TestNewEventGrantPermTokenHead(t *testing.T) {
return token.Permission(1 + rand.Intn(n))
}
- event := token.EventGrant{
+ event := token.EventGranted{
ContractId: str(),
Granter: str(),
Grantee: str(),
@@ -313,7 +313,7 @@ func TestNewEventGrantPermTokenBody(t *testing.T) {
return token.Permission(1 + rand.Intn(n))
}
- event := token.EventGrant{
+ event := token.EventGranted{
ContractId: str(),
Granter: str(),
Grantee: str(),
@@ -339,7 +339,7 @@ func TestNewEventRevokePermToken(t *testing.T) {
return token.Permission(1 + rand.Intn(n))
}
- event := token.EventAbandon{
+ event := token.EventRenounced{
ContractId: str(),
Grantee: str(),
Permission: permission(),
diff --git a/x/token/keeper/msg_server.go b/x/token/keeper/msg_server.go
index 58111076e8..d1407ad4d3 100644
--- a/x/token/keeper/msg_server.go
+++ b/x/token/keeper/msg_server.go
@@ -196,7 +196,7 @@ func (s msgServer) GrantPermission(c context.Context, req *token.MsgGrantPermiss
s.keeper.Grant(ctx, req.ContractId, granter, grantee, permission)
- event := token.EventGrant{
+ event := token.EventGranted{
ContractId: req.ContractId,
Granter: req.From,
Grantee: req.To,
@@ -222,7 +222,7 @@ func (s msgServer) RevokePermission(c context.Context, req *token.MsgRevokePermi
s.keeper.Abandon(ctx, req.ContractId, grantee, permission)
- event := token.EventAbandon{
+ event := token.EventRenounced{
ContractId: req.ContractId,
Grantee: req.From,
Permission: permission,
diff --git a/x/token/keeper/supply.go b/x/token/keeper/supply.go
index 903a2f1e8d..871390e00a 100644
--- a/x/token/keeper/supply.go
+++ b/x/token/keeper/supply.go
@@ -9,7 +9,7 @@ import (
func (k Keeper) Issue(ctx sdk.Context, class token.TokenClass, owner, to sdk.AccAddress, amount sdk.Int) {
k.issue(ctx, class)
- event := token.EventIssue{
+ event := token.EventIssued{
Creator: owner.String(),
ContractId: class.ContractId,
Name: class.Name,
@@ -35,7 +35,7 @@ func (k Keeper) Issue(ctx sdk.Context, class token.TokenClass, owner, to sdk.Acc
}
// legacy
- eventGrant := token.EventGrant{
+ eventGrant := token.EventGranted{
ContractId: class.ContractId,
Grantee: to.String(),
}
@@ -308,7 +308,7 @@ func (k Keeper) modify(ctx sdk.Context, contractID string, changes []token.Pair)
func (k Keeper) Grant(ctx sdk.Context, contractID string, granter, grantee sdk.AccAddress, permission token.Permission) {
k.grant(ctx, contractID, grantee, permission)
- event := token.EventGrant{
+ event := token.EventGranted{
ContractId: contractID,
Granter: granter.String(),
Grantee: grantee.String(),
@@ -331,7 +331,7 @@ func (k Keeper) grant(ctx sdk.Context, contractID string, grantee sdk.AccAddress
func (k Keeper) Abandon(ctx sdk.Context, contractID string, grantee sdk.AccAddress, permission token.Permission) {
k.deleteGrant(ctx, contractID, grantee, permission)
- event := token.EventAbandon{
+ event := token.EventRenounced{
ContractId: contractID,
Grantee: grantee.String(),
Permission: permission,
diff --git a/proto/lbm/token/v1/event.proto b/proto/lbm/token/v1/event.proto
index 44e8a22028..934628e090 100644
--- a/proto/lbm/token/v1/event.proto
+++ b/proto/lbm/token/v1/event.proto
@@ -91,10 +91,10 @@ message EventRevokedOperator {
string operator = 3;
}
// EventIssue is emitted when a new token class is created.
//
// Since: 0.46.0 (finschia)
-message EventIssue {
+message EventIssued {
// address which created the contract.
string creator = 1;
// contract id associated with the token class.
@@ -113,12 +113,12 @@ message EventIssue {
bool mintable = 8;
}
// EventGrant is emitted when a granter grants its permission to a grantee.
//
// Info: `granter` would be empty if the permission is granted by an issuance.
//
// Since: 0.46.0 (finschia)
-message EventGrant {
+message EventGranted {
// contract id associated with the token class.
string contract_id = 1;
// address which granted the permission to `grantee`.
@@ -130,10 +130,10 @@ message EventGrant {
Permission permission = 4;
}
// EventAbandon is emitted when a grantee abandons its permission.
//
// Since: 0.46.0 (finschia)
-message EventAbandon {
+message EventRenounced {
// contract id associated with the token class.
string contract_id = 1;
// address of the grantee which abandons its grant.
@@ -91,10 +91,10 @@ message EventRevokedOperator {
string operator = 3;
}
-// EventIssue is emitted when a new token class is created.
+// EventIssued is emitted when a new token class is created.
//
// Since: 0.46.0 (finschia)
@@ -113,12 +113,12 @@ message EventIssue {
bool mintable = 8;
}
-// EventGrant is emitted when a granter grants its permission to a grantee.
+// EventGranted is emitted when a granter grants its permission to a grantee.
//
// Info: `granter` would be empty if the permission is granted by an issuance.
@@ -130,10 +130,10 @@ message EventGrant {
Permission permission = 4;
}
-// EventAbandon is emitted when a grantee abandons its permission.
+// EventRenounced is emitted when a grantee renounces its permission.
//
// Since: 0.46.0 (finschia)